@@ -1,7 +1,6 @@
 #ifndef HEADER_UTILS_H
 #define HEADER_UTILS_H
 
-#include <stdio.h>
 #include <ctype.h>
 #include <assert.h>
 #include <sys/time.h>
@@ -16,9 +15,8 @@ const char *adjust_unit(double *ptr_bytes);
 /* Return true if @filename matches the regex /^[0-9]+\.h2w$/ */
 int is_my_file(const char *filename);
 
-/* @filename should be PATH_MAX long. */
-void full_fn_from_number(char *full_fn, const char **filename,
-	const char *path, int num);
+/* Caller must free(3) the returned pointer. */
+char *full_fn_from_number(const char **filename, const char *path, long num);
 
 static inline long delay_ms(const struct timeval *t1, const struct timeval *t2)
 {
@@ -26,22 +24,19 @@ static inline long delay_ms(const struct timeval *t1, const struct timeval *t2)
 		(t2->tv_usec - t1->tv_usec) / 1000;
 }
 
-/* Parse @param and return the start-at parameter.
- * The string must be of the format "--start-at=NUM"; otherwise it returns -1.
- */
-#define START_AT_TEXT "--start-at="
-int parse_start_at_param(const char *param);
+int parse_args(const char *name, int argc, char **argv,
+	long *pstart_at, long *pend_at, const char **ppath);
 
-const int *ls_my_files(const char *path, int start_at);
+const long *ls_my_files(const char *path, long start_at, long end_at);
 
-void print_header(FILE *f, char *name);
+void print_header(FILE *f, const char *name);
 
 static inline uint64_t random_number(uint64_t prv_number)
 {
 	return prv_number * 4294967311ULL + 17;
 }
 
-#ifdef APPLE_MAC
+#if __APPLE__ && __MACH__
 
 /* For function fcntl. */
 #include <fcntl.h>
@@ -70,6 +65,10 @@ static inline int posix_fadvise(int fd, off_t offset, off_t len, int advice)
 	}
 }
 
-#endif	/* APPLE_MAC */
+#endif	/* Apple Macintosh */
+
+#ifdef __FreeBSD__
+#define fdatasync(fd) fsync(fd)
+#endif
 
 #endif	/* HEADER_UTILS_H */
